summaryrefslogtreecommitdiffstats
path: root/bibletime/backend/cswordmoduleinfo.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:01:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:01:21 -0600
commitb3604f731cc45450d860d07be06fc050339de07a (patch)
tree339ae23dd7ec32f81d8feeed9c74cfc6e8108f2d /bibletime/backend/cswordmoduleinfo.cpp
parent3b005fadaa25c84a914d6889714a6f476afb8187 (diff)
downloadbibletime-b3604f731cc45450d860d07be06fc050339de07a.tar.gz
bibletime-b3604f731cc45450d860d07be06fc050339de07a.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'bibletime/backend/cswordmoduleinfo.cpp')
-rw-r--r--bibletime/backend/cswordmoduleinfo.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/bibletime/backend/cswordmoduleinfo.cpp b/bibletime/backend/cswordmoduleinfo.cpp
index ebb0cc3..77b46da 100644
--- a/bibletime/backend/cswordmoduleinfo.cpp
+++ b/bibletime/backend/cswordmoduleinfo.cpp
@@ -153,13 +153,13 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
(*m_module) = sword::TOP;
// This needs to use ::tqfromLatin1 because if the text is still locked,
// a lot of garbage will show up. It will also work with properly decrypted
// Unicode text, because all non-ASCII Unicode chars consist of bytes >127
// and therefore contain no control (nonprintable) characters, which are all <127.
TQString test = isUnicode()
? TQString::fromUtf8(m_module->getRawEntryBuf().c_str())
- : TQString::tqfromLatin1( m_module->getRawEntryBuf().c_str() );
+ : TQString::fromLatin1( m_module->getRawEntryBuf().c_str() );
if (test.isEmpty()) {
qWarning("Unlock key of module %s is NOT valid", name().latin1());
@@ -756,7 +756,7 @@ TQString CSwordModuleInfo::aboutText() const {
for (opts = CSwordModuleInfo::filterTypesMIN; opts <= CSwordModuleInfo::filterTypesMAX; ++opts) {
if (has(static_cast < CSwordModuleInfo::FilterTypes > (opts))) {
if (!options.isEmpty()) {
- options += TQString::tqfromLatin1(", ");
+ options += TQString::fromLatin1(", ");
}
options += CSwordBackend::translatedOptionName(static_cast < CSwordModuleInfo::FilterTypes > (opts));
@@ -871,7 +871,7 @@ const CLanguageMgr::Language * const CSwordModuleInfo::language() const {
TQString CSwordModuleInfo::getSimpleConfigEntry(const TQString& name) const {
TQString ret = isUnicode()
? TQString::fromUtf8(m_module->getConfigEntry(name.latin1()))
- : TQString::tqfromLatin1(m_module->getConfigEntry(name.latin1()));
+ : TQString::fromLatin1(m_module->getConfigEntry(name.latin1()));
return ret.isEmpty() ? TQString() : ret;
}
@@ -882,7 +882,7 @@ TQString CSwordModuleInfo::getFormattedConfigEntry(const TQString& name) const {
RTF_Filter.processText(RTF_Buffer, 0, 0);
TQString ret = isUnicode()
? TQString::fromUtf8(RTF_Buffer.c_str())
- : TQString::tqfromLatin1(RTF_Buffer.c_str());
+ : TQString::fromLatin1(RTF_Buffer.c_str());
return ret.isEmpty() ? TQString() : ret;
}
@@ -153,13 +153,13 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
(*m_module) = sword::TOP;
- // This needs to use ::tqfromLatin1 because if the text is still locked,
+ // This needs to use ::fromLatin1 because if the text is still locked,
// a lot of garbage will show up. It will also work with properly decrypted
// Unicode text, because all non-ASCII Unicode chars consist of bytes >127